@@ -259,7 +259,8 @@ class TestGetData:
 
     @pytest.mark.source
     @pytest.mark.get_data
-    def test_filters_by_custom_date_returns(self, good_object_id, get_three_good_field_ids, connector, filtered_column_nm):
+    def test_filters_by_custom_date_returns(self, good_object_id, get_three_good_field_ids, connector,
+                                            filtered_column_nm):
         connector.authenticate()
         data = connector.get_data(good_object_id,
                                   get_three_good_field_ids,
@@ -305,6 +306,102 @@ class TestGetData:
             assert start < datetime.strptime(row[filtered_column_nm], filtered_column_date_format)
             assert datetime.strptime(row[filtered_column_nm], filtered_column_date_format) < end
 
+    @pytest.mark.source
+    @pytest.mark.get_data
+    def test_filters_by_today_returns(self, good_object_id, get_three_good_field_ids, connector, filtered_column_nm):
+        connector.authenticate()
+        data = connector.get_data(good_object_id,
+                                  get_three_good_field_ids,
+                                  filters={
+                                      'filtered_column_nm': filtered_column_nm,
+                                      'start_selection_nm': "Custom Date",
+                                      'end_selection_nm': "Today",
+                                      'start_value_txt': "1941-03-26",
+                                      'end_value_txt': "",
+                                      'timezone_offset_nbr': "1"
+                                  })
+        assert data
+
+    @pytest.mark.source
+    @pytest.mark.get_data
+    def test_filters_by_today_works(self,
+                                    good_object_id,
+                                    get_three_good_field_ids,
+                                    connector,
+                                    filtered_column_nm,
+                                    filtered_column_date_format,
+                                    custom_date_start_val,
+                                    custom_date_end_val):
+        if filtered_column_nm not in get_three_good_field_ids:
+            get_three_good_field_ids.append(filtered_column_nm)
+        else:
+            get_three_good_field_ids
+        connector.authenticate()
+        data = connector.get_data(good_object_id,
+                                  get_three_good_field_ids,
+                                  filters={
+                                      'filtered_column_nm': filtered_column_nm,
+                                      'start_selection_nm': "Custom Date",
+                                      'end_selection_nm': "Today",
+                                      'start_value_txt': custom_date_start_val,
+                                      'end_value_txt': custom_date_end_val,
+                                      'timezone_offset_nbr': "1"
+                                  },
+                                  n_rows=5)
+        start = datetime.strptime(custom_date_start_val, "%Y-%m-%d")
+        end = datetime.utcnow() - datetime.timedelta(days=0, hours=int(1))
+        for row in data["data"]:
+            assert start < datetime.strptime(row[filtered_column_nm], filtered_column_date_format)
+            assert datetime.strptime(row[filtered_column_nm], filtered_column_date_format) < end
+
+    @pytest.mark.source
+    @pytest.mark.get_data
+    def test_filters_by_yesterday_returns(self, good_object_id, get_three_good_field_ids, connector, filtered_column_nm):
+        connector.authenticate()
+        data = connector.get_data(good_object_id,
+                                  get_three_good_field_ids,
+                                  filters={
+                                      'filtered_column_nm': filtered_column_nm,
+                                      'start_selection_nm': "Custom Date",
+                                      'end_selection_nm': "Yesterday",
+                                      'start_value_txt': "1941-03-26",
+                                      'end_value_txt': "",
+                                      'timezone_offset_nbr': "1"
+                                  })
+        assert data
+
+    @pytest.mark.source
+    @pytest.mark.get_data
+    def test_filters_by_yesterday_works(self,
+                                    good_object_id,
+                                    get_three_good_field_ids,
+                                    connector,
+                                    filtered_column_nm,
+                                    filtered_column_date_format,
+                                    custom_date_start_val,
+                                    custom_date_end_val):
+        if filtered_column_nm not in get_three_good_field_ids:
+            get_three_good_field_ids.append(filtered_column_nm)
+        else:
+            get_three_good_field_ids
+        connector.authenticate()
+        data = connector.get_data(good_object_id,
+                                  get_three_good_field_ids,
+                                  filters={
+                                      'filtered_column_nm': filtered_column_nm,
+                                      'start_selection_nm': "Custom Date",
+                                      'end_selection_nm': "Yesterday",
+                                      'start_value_txt': custom_date_start_val,
+                                      'end_value_txt': custom_date_end_val,
+                                      'timezone_offset_nbr': "1"
+                                  },
+                                  n_rows=5)
+        start = datetime.strptime(custom_date_start_val, "%Y-%m-%d")
+        end = datetime.utcnow() - datetime.timedelta(days=1, hours=int(1))
+        for row in data["data"]:
+            assert start < datetime.strptime(row[filtered_column_nm], filtered_column_date_format)
+            assert datetime.strptime(row[filtered_column_nm], filtered_column_date_format) < end
+
 
 class TestGetMetaData:
     @pytest.mark.destination
@@ -336,4 +433,3 @@ class TestGetMetaData:
     def test_returns_data_types(self, get_good_meta_data):
         data = get_good_meta_data
         assert "data_types" in data
-
